@@ -38,6 +38,8 @@ OPTS = [
                       'coordination.'),
     cfg.FloatOpt('check_watchers',
                  default=10.0,
+                 deprecated_for_removal=True,
+                 deprecated_reason='This parameter is no longer used.',
                  help='Number of seconds between checks to see if group '
                       'membership has changed'),
     cfg.IntOpt('retry_backoff',
